@@ -41,6 +41,8 @@
 
 #include "cvtest.h"
 
+#if 0
+
 /* Testing parameters */
 static char FuncName[] = "cvCalcOpticalFlowHS";
 static char TestName[] = "Optical flow (Horn & Schunck)";
@@ -48,8 +50,6 @@ static char TestClass[] = "Algorithm";
 
 static long lImageWidth;
 static long lImageHeight;
-static long  lNumIterations;
-static float flEpsilon;
 static float lambda;
 
 #define EPSILON 0.0001f
@@ -400,15 +400,15 @@ for( usePrevious = 0; usePrevious < 2; usePrevious++ )
 }
 
     /* Free memory */
-    cvFree( (void**)&VelocityX );
-    cvFree( (void**)&VelocityY );
-    cvFree( (void**)&auxVelocityX );
-    cvFree( (void**)&auxVelocityY );
+    cvFree( &VelocityX );
+    cvFree( &VelocityY );
+    cvFree( &auxVelocityX );
+    cvFree( &auxVelocityY );
 
 
-    cvFree( (void**)&DerX );
-    cvFree( (void**)&DerY );
-    cvFree( (void**)&DerT );
+    cvFree( &DerX );
+    cvFree( &DerY );
+    cvFree( &DerT );
 
     cvReleaseImage( &imgA );
     cvReleaseImage( &imgB );
@@ -426,4 +426,6 @@ void InitACalcOpticalFlowHS( void )
     trsReg( FuncName, TestName, TestClass, fmaCalcOpticalFlowHS );
 } /* InitACalcOpticalFlowHS */
 
+#endif
+
 /* End of file. */
